@@ -43,8 +43,10 @@ def fetch_data(raw_data_id):
 
 
 def display_data(raw_data_string, raw_data_id, model_folder):
-    logging.info("raw_data_id: %i", raw_data_id)
-    logging.info("raw data:\n%s", raw_data_string)
+    print("#### Raw Data (ID: %i)" % raw_data_id)
+    print("```")
+    print(raw_data_string)
+    print("```")
 
     PROJECT_ROOT = utils.get_project_root()
 
